@@ -9,7 +9,7 @@ import pytest
 def test_can_get_assets(mock_get_essential_details, api_session):
     asset = Asset(api_session)
     mock_get_essential_details.return_value = MagicMock()
-    asset.get_assets()
+    asset.list_assets()
     asset.get_essential_details.assert_called_with(
         "GET",
         f"{api_session.base_url}/api/{api_session.api_version}/assets",
@@ -21,7 +21,7 @@ def test_can_get_assets_by_filter(mock_get_essential_details, api_session):
     asset = Asset(api_session)
     mock_get_essential_details.return_value = MagicMock()
     test_data = {"asset_type": "mutual-fund"}
-    asset.get_assets(asset_type=test_data.get("asset_type"))
+    asset.list_assets(asset_type=test_data.get("asset_type"))
     asset.get_essential_details.assert_called_with(
         "GET",
         f"{api_session.base_url}/api/{api_session.api_version}/assets?asset_type=mutual-fund",
